python-hl7 is a simple library for parsing messages of Health Level 7 
(HL7) version 2.x into Python objects.

* Source Code: http://github.com/johnpaulett/python-hl7
* Documentation: http://python-hl7.readthedocs.org
* PyPi: http://pypi.python.org/pypi/hl7